' -------------------------------------------------------------------------------------------
' script : DisableWirelessNetworkAdapters.vbs
' author : R.Danard
' date   : 10-v-2011
' version: 1.1
' purpose: 
'  disable all wireless network cards 
'
' cscript DisableWirelessNetworkAdapters.vbs
' optional arguments:
'   - /verbose:yes -> switch to verbose logging, for debugging 
'   - /resetlog:no -> add tok the log file if already present  

' revision history
' 1.0 : original version
' 1.1 : force script to return exit code 0
' -------------------------------------------------------------------------------------------

' force the declaration of all variables
option explicit

' ===========================================================================================
' constants declaration
' ===========================================================================================

' file management
Const OpenAsASCII   = 0
Const OpenAsUnicode = -1

' FileSystemObject.CreateTextFile
Const OverwriteIfExist = -1
Const FailIfExist      = 0

' FileSystemObject.OpenTextFile
Const OpenAsDefault    = -2
Const CreateIfNotExist = -1
Const FailIfNotExist   = 0
Const ForReading   = 1
Const ForWriting   = 2
Const ForAppending = 8

' Log

Const LOG_IDENT     = "DisableWirelessNetworkAdapters"
const LOG_DIR       = "C:\_logfiles"

' Registry
const HKEY_CURRENT_USER  = &H80000001
const HKEY_LOCAL_MACHINE = &H80000002
const HKEY_CLASSES_ROOT  = &H80000000
const HKEY_USERS         = &H80000003

Const KEY_QUERY_VALUE    = &H1
Const KEY_SET_VALUE      = &H2
Const KEY_CREATE_SUB_KEY = &H4
Const DELETE             = &H10000

const REG_SZ        = 1
const REG_EXPAND_SZ = 2
const REG_BINARY    = 3
const REG_DWORD     = 4
const REG_MULTI_SZ  = 7

' ===========================================================================================
' global variables declaration
' ===========================================================================================

Dim g_objWshShell
Dim g_strCurDir
Dim g_strScriptDir
Dim g_objFSO
Dim g_strLocalComputer
Dim g_strDomainFQDN
Dim g_strLogDir
dim g_strLogFileName 
Dim g_objReg
Dim g_objFileSystem
dim g_blnVerboseLog
dim g_blnResetLog
Dim g_objShellApplication

' ===========================================================================================
' beginning of the script
' ===========================================================================================

Call Init()

Call InitLog()

Call DoWork()

Call FinalizeLog()

wscript.quit(0)
' ===========================================================================================
' procedures and functions 
' ===========================================================================================

' -------------------------------------------------------------------------------------------
' Sub DoWork() 
'
' Purpose:
'   main subroutine
'	list the wireless connections
'   disable all wireless connections found
'
' Input:
' - none 
'
' Output:
' - none 
'
' -------------------------------------------------------------------------------------------

Sub DoWork()

	Dim strKeyPath
	Dim arrConnectionsNames
	Dim arrConnectionsIDs
	
 'registry entry to look for network cards on the system   
	strKeyPath = "SYSTEM\CurrentControlSet\Control\Network\{4D36E972-E325-11CE-BFC1-08002BE10318}"

	ReDim arrConnectionsNames(0)
	ReDim arrConnectionsIDs(0)
	
	WriteLog "Looking for Wireless connections..."
	WriteLog ""
	
	Call EnumerateWiFiConnections (strKeyPath,arrConnectionsNames,arrConnectionsIDs)
	
	If UBound(arrConnectionsNames) > 0 Then 
		WriteLog ""	
		WriteLog "...done"
		WriteLog ""	
		WriteLog "Disabling Wireless connections..."
		WriteLog ""	
		Call DisableWiFiConnections(arrConnectionsNames,arrConnectionsIDs)
		WriteLog ""	
		WriteLog "...done"
	Else
		WriteLog "No wireless connection found"
	End If 
	
End Sub 

' -------------------------------------------------------------------------------------------
' Sub EnumerateWiFiConnections(strKeyPath,arrConnectionsNames_Ret,arrConnectionsIDs_Ret) 
'
' Purpose:
'   retrieve the list of WiFi adapters
'
' Input:
' - strKeyPath: reg keypath to read 
'
' Output:
' - arrConnectionsNames_Ret: array of connexions names 
' - arrConnectionsIDs_Ret  : array of connexions IDs
'
' -------------------------------------------------------------------------------------------

Sub EnumerateWiFiConnections(strKeyPath,arrConnectionsNames_Ret,arrConnectionsIDs_Ret)

	Dim arrSubKeys
	Dim strSubkey
	Dim strValueName
	Dim dwValue
	Dim strValue
	Dim intNb
	
  g_objReg.EnumKey HKEY_LOCAL_MACHINE, strKeyPath, arrSubkeys 

  If IsArray(arrSubkeys) Then
  	For Each strSubkey In arrSubKeys 
    	If strSubkey <> "Descriptions" Then
      	strValueName = "MediaSubType"
      	g_objReg.GetDWORDValue HKEY_LOCAL_MACHINE,strKeyPath & "\" & strSubkey & "\" & "Connection",strValueName,dwValue
      	' dwValue = 1: LAN  (built-in)
        ' dwValue = 2: WiFi
      	If dwValue = 2 Then
        		strValueName = "Name"
        		g_objReg.GetStringValue HKEY_LOCAL_MACHINE,strKeyPath & "\" & strSubkey & "\" & "Connection",strValueName,strValue
        		intNb = UBound(arrConnectionsNames_Ret)+1
        		ReDim Preserve arrConnectionsNames_Ret(intNb)
        		ReDim Preserve arrConnectionsIDs_Ret(intNb)
        		arrConnectionsNames_Ret(intNb) = strValue
        		WriteLog "connection #" & intNb & " - " & strValue
            strValueName = "PnpInstanceID"
            g_objReg.GetStringValue HKEY_LOCAL_MACHINE,strKeyPath & "\" & strSubkey & "\" & "Connection",strValueName,strValue
            arrConnectionsIDs_Ret(intNb) = strValue
      	End If
    	End If
    Next
  End If

End Sub

' -------------------------------------------------------------------------------------------
' Sub DisableWiFiConnections(arrConnectionsNames,arrConnectionsIDs) 
'
' Purpose:
'   disable the WiFi connections, using devcon.exe
'
' Input:
' - arrConnectionsNames: array of connexions names 
' - arrConnectionsIDs  : array of connexions IDs'
'
' Output:
' - none 
'
' -------------------------------------------------------------------------------------------

Sub DisableWiFiConnections(arrConnectionsNames,arrConnectionsIDs)

	Dim intNr
	Dim objExec
	Dim strCommand
	
	For intNr = 1 to UBound(arrConnectionsNames)
		WriteLog "disabling '" & arrConnectionsNames(intNr) & "'..."
    	strCommand = """" & g_strScriptDir & "\devcon.exe"" disable ""@" & arrConnectionsIDs(intNr) & """" 
   		Set objExec = g_objWshShell.Exec(strCommand)
		Do Until objExec.Status
			WScript.Sleep 250 
		Loop 
    	WriteLog objExec.StdOut.ReadAll()
	Next 
	
End Sub

' ===========================================================================================
' initializations
' ===========================================================================================

' -------------------------------------------------------------------------------------------
' Sub Init() 
'
' Purpose:
'   initialize global variables
'
' Input:
' - none
'
' Output:
' - none 
'
' -------------------------------------------------------------------------------------------

Sub Init()

    dim strPath
    dim objFile
    
    On Error Resume Next
    
    Err.Clear
    
    Set g_objWshShell = CreateObject("WScript.Shell")
    Set g_objFileSystem = CreateObject("Scripting.FileSystemObject")
    Set g_objShellApplication = CreateObject("Shell.Application")
    
    g_strCurDir = g_objWshShell.CurrentDirectory 
    
    ' log dir is initialized to the constant value defined above
    ' if the folder doesn't exist, the value will be later modified to a subfolder of %Temp%
    g_strLogDir = LOG_DIR
    
    Set g_objFSO = CreateObject("Scripting.FileSystemObject")
    
    g_strLocalComputer = ucase(g_objWshShell.ExpandEnvironmentStrings("%ComputerName%"))

    Set g_objReg = GetObject("winmgmts:{impersonationLevel=impersonate}!\\" & g_strLocalComputer & "\root\default:StdRegProv")

    strPath = Wscript.ScriptFullName

    Set objFile = g_objFSO.GetFile(strPath)
    g_strScriptDir = g_objFSO.GetParentFolderName(objFile) 
    
    On Error goto 0

End Sub

' -------------------------------------------------------------------------------------------
' Sub ReadCmdLineArgs()
'
' Purpose:
'   Read the command line arguments
'
' Input:
' - none 
'
' Output:
' - none 
'
' -------------------------------------------------------------------------------------------

sub ReadCmdLineArgs()

    if wscript.arguments.count = 0 then
      exit sub
    end if
        
    if Trim(WScript.Arguments.Named("verbose")) = "yes" then
      g_blnVerboseLog = true
    else
      g_blnVerboseLog = false
    end if

    if Trim(WScript.Arguments.Named("resetlog")) = "no" then
      g_blnResetLog = false
    else
      g_blnResetLog = true
    end if

end sub


' ===========================================================================================
' sdk procedures and functions
' ===========================================================================================

' -------------------------------------------------------------------------------------------
' Sub InitLog ()
'
' Purpose:
'   Initialize the log file
'
' Input:
' - none
'
' Output:
' - the log folder is created if not present
' - the start-of-script message is written in the Log
'
' -------------------------------------------------------------------------------------------

Sub InitLog ()

    Dim oLogFile
    Dim strDir
    Dim strCheckFileID
    
    g_strLogDir = g_objWshShell.ExpandEnvironmentStrings(g_strLogDir)

    If Right(g_strLogDir,1) = "\" Then
        strDir = mid(g_strLogDir,1,Len(g_strLogDir)-1)
    Else
        strDir = g_strLogDir
    End If 
    
    If not g_objFileSystem.FolderExists(strDir) Then
        Call CreateFolder(strDir)
        If not g_objFileSystem.FolderExists(strDir) Then
            strDir = g_objWshShell.ExpandEnvironmentStrings("%Temp%\Logs")
            Call CreateFolder(strDir)
        End If 
    End If

    g_strLogDir = strDir & "\"
    
    ' log file
    
    g_strLogFileName = g_strLogDir & LOG_IDENT & ".Log"
    
    ' don't overwrite the file if it exists and must be kept
    If (not g_objFileSystem.FileExists(g_strLogFileName)) or g_blnResetLog Then
        Set oLogFile = g_objFileSystem.CreateTextFile(g_strLogFileName,True)
    Else 
        Set oLogFile = g_objFileSystem.OpenTextFile(g_strLogFileName)            
    End If 
    
    oLogFile.Close
        
    On error goto 0
    
    WriteLog ("====================================================== ")
    WriteLog ("Starting script")
    WriteLog ("====================================================== ")
    
End Sub

' -------------------------------------------------------------------------------------------
' Sub FinalizeLog()
'
' Purpose:
'   end writing to the Log
'
' Input:
' - none
'
' Output:
' - the end-of-script message is written In the log
'
' Note:
'   no error handling
'
' -------------------------------------------------------------------------------------------

Sub FinalizeLog()

  WriteLog ("====================================================== ")
  WriteLog ("Ending script")
  WriteLog ("====================================================== ")
	
End Sub

' -------------------------------------------------------------------------------------------
' Sub WriteLog (strMessage)
' 
' Purpose:
'   write a message to the Log
' 
' Input:
' - message to write
' 
' Output:
' - the message is written in the Log
'
' Note:
'   no error handling
'
' -------------------------------------------------------------------------------------------

Sub WriteLog (strMessage)

    Dim objLogFile
    
    on error resume Next
    
    Set objLogFile = g_objFileSystem.OpenTextFile (g_strLogFileName,ForAppending)
    objLogFile.Writeline Now & " " & strMessage
    objLogFile.Close
    
    on error goto 0
    
End Sub

' -------------------------------------------------------------------------------------------
' Sub CreateFolder(strFolderName) 
' 
' Purpose:
'   create a folder, including higher level folders if not present
'
' Input:
' - strFolderName: name of the folder to create (full path)
'
' Output:
' - the folder is created 
'   if there is an error, then a message is written in the log and the sub exits
'
' -------------------------------------------------------------------------------------------

Sub CreateFolder(strFolderName)

  if g_blnVerboseLog then WriteLog " CreateFolder"

    Dim arrPath
    Dim intNr
    Dim strPath
    Dim intStart
    
    arrPath = Split(strFolderName,"\")
    
    ' check if we are creating a folder on a network share 
    ' it starts with \\, so:
    ' - arrPath(0) is empty,
    ' - arrPath(1) is the server name
    ' - arrPath(2) is the share name 
    strPath = arrPath(0)

    If strPath = "" Then
        strPath = strPath & "\" & arrPath(1) & "\" & arrPath(2)
        intStart = 3
    Else
        intStart = 1
    End If
    
    For intNr = intStart To UBound(arrPath)
        strPath = strPath & "\" & arrPath(intNr)
        If not g_objFileSystem.FolderExists(strPath) Then
            on error resume next 
            g_objFileSystem.CreateFolder strPath
            on error goto 0
            if err then
              WriteLog "unable to create folder '" & strPath & "' - error " & err.number & ": " & err.description
              exit sub
            end if 
        End If 
    Next
         
End Sub     

' -------------------------------------------------------------------------------------------
' end of the script
' -------------------------------------------------------------------------------------------
